==> spip_4.1.7+dfsg.orig.tar.xz: ecrire/lang/public_fr_tu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=fr_tu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Accueil',
	'article' => 'Article',
	'articles' => 'Articles',
	'articles_auteur' => 'Articles de cet auteur',
	'articles_populaires' => 'Articles les plus populaires',
	'articles_rubrique' => 'Articles de cette rubrique',
	'aucun_article' => 'Il n’y a pas d’article à cette adresse',
	'aucun_auteur' => 'Il n’y a pas d’auteur à cette adresse',
	'aucun_site' => 'Il n’y a pas de site à cette adresse',
	'aucune_breve' => 'Il n’y a pas de brève à cette adresse',
	'aucune_rubrique' => 'Il n’y a pas de rubrique à cette adresse',
	'auteur' => 'Auteur',
	'autres' => 'Autres',
	'autres_breves' => 'Autres brèves',
	'autres_groupes_mots_clefs' => 'Autres groupes de mots-clés',
	'autres_sites' => 'Autres sites',

	// B
	'bonjour' => 'Salut',

	// C
	'commenter_site' => 'Commenter ce site',
	'contact' => 'Contact',
	'copie_document_impossible' => 'Impossible de copier le document',

	// D
	'date' => 'Date',
	'dernier_ajout' => 'Dernier ajout',
	'dernieres_breves' => 'Dernières brèves',
	'derniers_articles' => 'Derniers articles',
	'derniers_commentaires' => 'Derniers commentaires',
	'derniers_messages_forum' => 'Derniers messages publiés dans les forums',

	// E
	'edition_mode_texte' => 'Édition en mode texte de',
	'en_reponse' => 'En réponse à :',
	'en_resume' => 'En résumé',
	'envoyer_message' => 'Envoyer un message',
	'espace_prive' => 'Espace privé',

	// F
	'formats_acceptes' => 'Formats acceptés : @formats@.',

	// H
	'hierarchie_site' => 'Hiérarchie du site',

	// J
	'jours' => 'jours',

	// L
	'lien_connecter' => 'Se connecter',

	// M
	'meme_auteur' => 'Du même auteur',
	'meme_rubrique' => 'Dans la même rubrique',
	'memes_auteurs' => 'Des mêmes auteurs',
	'message' => 'Message',
	'messages_forum' => 'Messages',
	'messages_recents' => 'Messages de forums les plus récents',
	'mots_clef' => 'Mot-clé',
	'mots_clefs' => 'Mots-clés',
	'mots_clefs_meme_groupe' => 'Mots-clés dans le même groupe',

	// N
	'navigation' => 'Navigation',
	'nom' => 'Nom',
	'nouveautes' => 'Les nouveautés',
	'nouveautes_web' => 'Nouveautés sur le Web',
	'nouveaux_articles' => 'Nouveaux articles',
	'nouvelles_breves' => 'Nouvelles brèves',

	// P
	'page_precedente' => 'page précédente',
	'page_suivante' => 'page suivante',
	'par_auteur' => 'par ',
	'participer_site' => 'Tu peux participer à la vie de ce site et proposer tes propres articles en t’inscrivant ci-dessous. Tu recevras immédiatement un email t’indiquant tes codes d’accès à l’espace privé du site.',
	'plan_site' => 'Plan du site',
	'popularite' => 'Popularité',
	'poster_message' => 'Poster un message',
	'proposer_site' => 'Tu peux proposer un site à ajouter dans cette rubrique :',

	// R
	'repondre_article' => 'Répondre à cet article',
	'repondre_breve' => 'Répondre à cette brève',
	'resultats_recherche' => 'Résultats de la recherche',
	'retour_debut_forums' => 'Retour au début des forums',
	'rss_abonnement' => 'Copie l’URL suivante dans ton agrégateur :',
	'rss_abonnement_titre' => 'S’abonner',
	'rss_abonnement_titre_page' => 'S’abonner à',
	'rss_explication' => 'Un fil RSS recueille les informations de mise à jour d’un site. Il fournit le contenu des billets ou des commentaires ou un extrait de ceux-ci, ainsi qu’un lien vers les versions complètes et quelques autres informations. Ce fil a pour vocation d’être lu par un agrégateur RSS.',
	'rss_explication_titre' => 'Qu’est-ce qu’un flux RSS ?',
	'rubrique' => 'Rubrique',
	'rubriques' => 'Rubriques',

	// S
	'signatures_petition' => 'Signatures',
	'site_realise_avec_spip' => 'Site réalisé avec SPIP',
	'sites_web' => 'Sites Web',
	'sous_rubriques' => 'Sous-rubriques',
	'spam' => 'Spam',
	'suite' => 'suite',
	'sur_web' => 'Sur le Web',
	'syndiquer_rubrique' => 'Syndiquer cette rubrique',
	'syndiquer_site' => 'Syndiquer tout le site',

	// T
	'texte_lettre_information' => 'Voici la lettre d’information du site',
	'texte_lettre_information_2' => 'Cette lettre recense les articles et les brèves publiés depuis',

	// V
	'ver_imprimer' => 'Version à imprimer',
	'voir_en_ligne' => 'Voir en ligne',
	'voir_squelette' => 'voir le squelette de cette page'
);

==> spip_4.4.7+dfsg.orig.tar.xz: ecrire/lang/public_fr_tu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=fr_tu
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Accueil',
	'article' => 'Article',
	'articles' => 'Articles',
	'articles_auteur' => 'Articles de cet auteur',
	'articles_populaires' => 'Articles les plus populaires',
	'articles_rubrique' => 'Articles de cette rubrique',
	'aucun_article' => 'Il n’y a pas d’article à cette adresse',
	'aucun_auteur' => 'Il n’y a pas d’auteur à cette adresse',
	'aucun_site' => 'Il n’y a pas de site à cette adresse',
	'aucune_breve' => 'Il n’y a pas de brève à cette adresse',
	'aucune_rubrique' => 'Il n’y a pas de rubrique à cette adresse',
	'auteur' => 'Auteur',
	'autres' => 'Autres',
	'autres_breves' => 'Autres brèves',
	'autres_groupes_mots_clefs' => 'Autres groupes de mots-clés',
	'autres_sites' => 'Autres sites',

	// B
	'bonjour' => 'Salut',

	// C
	'commenter_site' => 'Commenter ce site',
	'contact' => 'Contact',
	'copie_document_impossible' => 'Impossible de copier le document',

	// D
	'date' => 'Date',
	'dernier_ajout' => 'Dernier ajout',
	'dernieres_breves' => 'Dernières brèves',
	'derniers_articles' => 'Derniers articles',
	'derniers_commentaires' => 'Derniers commentaires',
	'derniers_messages_forum' => 'Derniers messages publiés dans les forums',

	// E
	'edition_mode_texte' => 'Édition en mode texte de',
	'en_reponse' => 'En réponse à :',
	'en_resume' => 'En résumé',
	'envoyer_message' => 'Envoyer un message',
	'espace_prive' => 'Espace privé',

	// F
	'formats_acceptes' => 'Formats acceptés : @formats@.',

	// H
	'hierarchie_site' => 'Hiérarchie du site',

	// J
	'jours' => 'jours',

	// L
	'lien_connecter' => 'Se connecter',

	// M
	'meme_auteur' => 'Du même auteur',
	'meme_rubrique' => 'Dans la même rubrique',
	'memes_auteurs' => 'Des mêmes auteurs',
	'message' => 'Message',
	'messages_forum' => 'Messages',
	'messages_recents' => 'Messages de forums les plus récents',
	'mots_clef' => 'Mot-clé',
	'mots_clefs' => 'Mots-clés',
	'mots_clefs_meme_groupe' => 'Mots-clés dans le même groupe',

	// N
	'navigation' => 'Navigation',
	'nom' => 'Nom',
	'nouveautes' => 'Les nouveautés',
	'nouveautes_web' => 'Nouveautés sur le Web',
	'nouveaux_articles' => 'Nouveaux articles',
	'nouvelles_breves' => 'Nouvelles brèves',

	// P
	'page_precedente' => 'page précédente',
	'page_suivante' => 'page suivante',
	'par_auteur' => 'par ',
	'participer_site' => 'Tu peux participer à la vie de ce site et proposer tes propres articles en t’inscrivant ci-dessous. Tu recevras immédiatement un email t’indiquant tes codes d’accès à l’espace privé du site.',
	'plan_site' => 'Plan du site',
	'popularite' => 'Popularité',
	'poster_message' => 'Poster un message',
	'proposer_site' => 'Tu peux proposer un site à ajouter dans cette rubrique :',

	// R
	'repondre_article' => 'Répondre à cet article',
	'repondre_breve' => 'Répondre à cette brève',
	'resultats_recherche' => 'Résultats de la recherche',
	'retour_debut_forums' => 'Retour au début des forums',
	'rss_abonnement' => 'Copie l’URL suivante dans ton agrégateur :',
	'rss_abonnement_titre' => 'S’abonner',
	'rss_abonnement_titre_page' => 'S’abonner à',
	'rss_explication' => 'Un fil RSS recueille les informations de mise à jour d’un site. Il fournit le contenu des billets ou des commentaires ou un extrait de ceux-ci, ainsi qu’un lien vers les versions complètes et quelques autres informations. Ce fil a pour vocation d’être lu par un agrégateur RSS.',
	'rss_explication_titre' => 'Qu’est-ce qu’un flux RSS ?',
	'rubrique' => 'Rubrique',
	'rubriques' => 'Rubriques',

	// S
	'signatures_petition' => 'Signatures',
	'site_realise_avec_spip' => 'Site réalisé avec SPIP',
	'sites_web' => 'Sites Web',
	'sous_rubriques' => 'Sous-rubriques',
	'spam' => 'Spam',
	'suite' => 'suite',
	'sur_web' => 'Sur le Web',
	'syndiquer_rubrique' => 'Syndiquer cette rubrique',
	'syndiquer_site' => 'Syndiquer tout le site',

	// T
	'texte_lettre_information' => 'Voici la lettre d’information du site',
	'texte_lettre_information_2' => 'Cette lettre recense les articles et les brèves publiés depuis',

	// V
	'ver_imprimer' => 'Version à imprimer',
	'voir_en_ligne' => 'Voir en ligne',
	'voir_squelette' => 'voir le squelette de cette page',
];
